Django Rest Framework HQ (Filter Extensions and support for ElasticSearch)


# Change Log

    0.1.2   Removed permission classes, project specific
    0.1.1   Removed _index from more_like_this (causing issue with ES2)
    0.1.0   Imported